# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import json
import warnings
import pulumi
import pulumi.runtime
from typing import Union
from . import utilities, tables

class ZoneLockdown(pulumi.CustomResource):
    configurations: pulumi.Output[list]
    """
    A list of IP addresses or IP ranges to match the request against specified in target, value pairs.  It's a complex value. See description below.   The order of the configuration entries is unimportant.

      * `target` (`str`) - The request property to target. Allowed values: "ip", "ip_range"
      * `value` (`str`) - The value to target. Depends on target's type. IP addresses should just be standard IPv4/IPv6 notation i.e. `198.51.100.4` or `2001:db8::/32` and IP ranges in CIDR format i.e. `198.51.0.0/16`.
    """
    description: pulumi.Output[str]
    """
    A description about the lockdown entry. Typically used as a reminder or explanation for the lockdown.
    """
    paused: pulumi.Output[bool]
    """
    Boolean of whether this zone lockdown is currently paused. Default: false.
    """
    priority: pulumi.Output[float]
    urls: pulumi.Output[list]
    """
    A list of simple wildcard patterns to match requests against. The order of the urls is unimportant.
    """
    zone_id: pulumi.Output[str]
    """
    The DNS zone ID to which the access rule should be added.
    """
    def __init__(__self__, resource_name, opts=None, configurations=None, description=None, paused=None, priority=None, urls=None, zone_id=None, __props__=None, __name__=None, __opts__=None):
        """
        Provides a Cloudflare Zone Lockdown resource. Zone Lockdown allows you to define one or more URLs (with wildcard matching on the domain or path) that will only permit access if the request originates from an IP address that matches a safelist of one or more IP addresses and/or IP ranges.

        ## Example Usage



        ```python
        import pulumi
        import pulumi_cloudflare as cloudflare

        # Restrict access to these endpoints to requests from a known IP address.
        endpoint_lockdown = cloudflare.ZoneLockdown("endpointLockdown",
            configurations=[{
                "target": "ip",
                "value": "198.51.100.4",
            }],
            description="Restrict access to these endpoints to requests from a known IP address",
            paused="false",
            urls=["api.mysite.com/some/endpoint*"],
            zone_id="d41d8cd98f00b204e9800998ecf8427e")
        ```


        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[list] configurations: A list of IP addresses or IP ranges to match the request against specified in target, value pairs.  It's a complex value. See description below.   The order of the configuration entries is unimportant.
        :param pulumi.Input[str] description: A description about the lockdown entry. Typically used as a reminder or explanation for the lockdown.
        :param pulumi.Input[bool] paused: Boolean of whether this zone lockdown is currently paused. Default: false.
        :param pulumi.Input[list] urls: A list of simple wildcard patterns to match requests against. The order of the urls is unimportant.
        :param pulumi.Input[str] zone_id: The DNS zone ID to which the access rule should be added.

        The **configurations** object supports the following:

          * `target` (`pulumi.Input[str]`) - The request property to target. Allowed values: "ip", "ip_range"
          * `value` (`pulumi.Input[str]`) - The value to target. Depends on target's type. IP addresses should just be standard IPv4/IPv6 notation i.e. `198.51.100.4` or `2001:db8::/32` and IP ranges in CIDR format i.e. `198.51.0.0/16`.
        """
        if __name__ is not None:
            warnings.warn("explicit use of __name__ is deprecated", DeprecationWarning)
            resource_name = __name__
        if __opts__ is not None:
            warnings.warn("explicit use of __opts__ is deprecated, use 'opts' instead", DeprecationWarning)
            opts = __opts__
        if opts is None:
            opts = pulumi.ResourceOptions()
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.version is None:
            opts.version = utilities.get_version()
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = dict()

            if configurations is None:
                raise TypeError("Missing required property 'configurations'")
            __props__['configurations'] = configurations
            __props__['description'] = description
            __props__['paused'] = paused
            __props__['priority'] = priority
            if urls is None:
                raise TypeError("Missing required property 'urls'")
            __props__['urls'] = urls
            if zone_id is None:
                raise TypeError("Missing required property 'zone_id'")
            __props__['zone_id'] = zone_id
        super(ZoneLockdown, __self__).__init__(
            'cloudflare:index/zoneLockdown:ZoneLockdown',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name, id, opts=None, configurations=None, description=None, paused=None, priority=None, urls=None, zone_id=None):
        """
        Get an existing ZoneLockdown resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param str id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[list] configurations: A list of IP addresses or IP ranges to match the request against specified in target, value pairs.  It's a complex value. See description below.   The order of the configuration entries is unimportant.
        :param pulumi.Input[str] description: A description about the lockdown entry. Typically used as a reminder or explanation for the lockdown.
        :param pulumi.Input[bool] paused: Boolean of whether this zone lockdown is currently paused. Default: false.
        :param pulumi.Input[list] urls: A list of simple wildcard patterns to match requests against. The order of the urls is unimportant.
        :param pulumi.Input[str] zone_id: The DNS zone ID to which the access rule should be added.

        The **configurations** object supports the following:

          * `target` (`pulumi.Input[str]`) - The request property to target. Allowed values: "ip", "ip_range"
          * `value` (`pulumi.Input[str]`) - The value to target. Depends on target's type. IP addresses should just be standard IPv4/IPv6 notation i.e. `198.51.100.4` or `2001:db8::/32` and IP ranges in CIDR format i.e. `198.51.0.0/16`.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = dict()

        __props__["configurations"] = configurations
        __props__["description"] = description
        __props__["paused"] = paused
        __props__["priority"] = priority
        __props__["urls"] = urls
        __props__["zone_id"] = zone_id
        return ZoneLockdown(resource_name, opts=opts, __props__=__props__)
    def translate_output_property(self, prop):
        return tables._CAMEL_TO_SNAKE_CASE_TABLE.get(prop) or prop

    def translate_input_property(self, prop):
        return tables._SNAKE_TO_CAMEL_CASE_TABLE.get(prop) or prop

